PyR3.shortcut package
=====================

Submodules
----------

PyR3.shortcut.context module
----------------------------

.. automodule:: PyR3.shortcut.context
   :members:
   :undoc-members:
   :show-inheritance:

PyR3.shortcut.edit module
-------------------------

.. automodule:: PyR3.shortcut.edit
   :members:
   :undoc-members:
   :show-inheritance:

PyR3.shortcut.io module
-----------------------

.. automodule:: PyR3.shortcut.io
   :members:
   :undoc-members:
   :show-inheritance:

PyR3.shortcut.material module
-----------------------------

.. automodule:: PyR3.shortcut.material
   :members:
   :undoc-members:
   :show-inheritance:

PyR3.shortcut.mesh module
-------------------------

.. automodule:: PyR3.shortcut.mesh
   :members:
   :undoc-members:
   :show-inheritance:

PyR3.shortcut.modifiers module
------------------------------

.. automodule:: PyR3.shortcut.modifiers
   :members:
   :undoc-members:
   :show-inheritance:

PyR3.shortcut.transform module
------------------------------

.. automodule:: PyR3.shortcut.transform
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: PyR3.shortcut
   :members:
   :undoc-members:
   :show-inheritance:
